@@ -1,4 +1,4 @@
-use gdk::Rectangle;
+use gtk::{gdk::Rectangle, gio, glib};
 use std::path::PathBuf;
 
 use crate::{image::PreviewSize, image_operation::ImageOperation};
@@ -14,9 +14,11 @@ pub enum Event {
     StartSelection((i32, i32)),
     DragSelection((i32, i32)),
     SaveCurrentImage(Option<PathBuf>),
+    DeleteCurrentImage,
     EndSelection,
     PreviewSmaller,
     PreviewLarger,
+    PreviewFitScreen,
     NextImage,
     PreviousImage,
     RefreshFileList,
